@@ -97,7 +97,7 @@ impl EngineAction for Brawl {
                     defender_update.extra_tiredness += TirednessCost::CRITICAL;
                     format!(
                         "A brawl between {} and {}! {} got {} good with the hook! That'll be an ugly scar.",
-                        defender.info.shortened_name(), attacker.info.shortened_name(), attacker.info.shortened_name(), defender.info.pronouns.as_object()
+                        defender.info.short_name(), attacker.info.short_name(), attacker.info.short_name(), defender.info.pronouns.as_object()
                     )
                 } else {
                     defender_update.extra_tiredness += TirednessCost::SEVERE;
@@ -105,45 +105,45 @@ impl EngineAction for Brawl {
                     [
                         format!(
                             "A brawl between {} and {}! {} seems to have gotten the upper hand.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            attacker.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            attacker.info.short_name()
                         ),
                         format!(
                             "An intense clash between {} and {} ends with {} coming out on top!",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            attacker.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            attacker.info.short_name()
                         ),
                         format!(
                             "A fierce fight between {} and {} concludes with {} gaining the upper hand!",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            attacker.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            attacker.info.short_name()
                         ),
                         format!(
                             "{} and {} engage in a heated scuffle, but {} emerges the winner.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            attacker.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            attacker.info.short_name()
                         ),
                         format!(
                             "It's {} versus {} in a wild brawl! {} prevails in the end.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            attacker.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            attacker.info.short_name()
                         ),
                         format!(
                             "{} and {} come to blows during the game. {} manages to give the best shots.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            attacker.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            attacker.info.short_name()
                         ),
                         format!(
                             "The battle between {} and {} wraps up with {} as the victor.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            attacker.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            attacker.info.short_name()
                         ),
                     ]
                     .choose(rng)
@@ -163,33 +163,33 @@ impl EngineAction for Brawl {
                 [
                     format!(
                         "A brawl between {} and {}! They both got some damage.",
-                        attacker.info.shortened_name(),
-                        defender.info.shortened_name()
+                        attacker.info.short_name(),
+                        defender.info.short_name()
                     ),
                     format!(
                         "A brawl between {} and {}! An even match.",
-                        defender.info.shortened_name(),
-                        attacker.info.shortened_name()
+                        defender.info.short_name(),
+                        attacker.info.short_name()
                     ),
                     format!(
                         "A fierce clash! {} and {} trade powerful blows.",
-                        attacker.info.shortened_name(),
-                        defender.info.shortened_name()
+                        attacker.info.short_name(),
+                        defender.info.short_name()
                     ),
                     format!(
                         "{} and {} collide in an intense struggle! Neither backs down.",
-                        attacker.info.shortened_name(),
-                        defender.info.shortened_name()
+                        attacker.info.short_name(),
+                        defender.info.short_name()
                     ),
                     format!(
                         "{} strikes first, but {} quickly counters! An even fight.",
-                        attacker.info.shortened_name(),
-                        defender.info.shortened_name()
+                        attacker.info.short_name(),
+                        defender.info.short_name()
                     ),
                     format!(
                         "{} tries to outmaneuver {}, but the fight remains deadlocked.",
-                        attacker.info.shortened_name(),
-                        defender.info.shortened_name()
+                        attacker.info.short_name(),
+                        defender.info.short_name()
                     ),
                 ]
                 .choose(rng)
@@ -206,7 +206,7 @@ impl EngineAction for Brawl {
                     attacker_update.extra_tiredness += TirednessCost::CRITICAL;
                     format!(
                         "A brawl between {} and {}! {} got {} good with the hook! That'll be an ugly scar.",
-                        attacker.info.shortened_name(), defender.info.shortened_name(), defender.info.shortened_name(), attacker.info.pronouns.as_object()
+                        attacker.info.short_name(), defender.info.short_name(), defender.info.short_name(), attacker.info.pronouns.as_object()
                     )
                 } else {
                     attacker_update.extra_tiredness += TirednessCost::SEVERE;
@@ -214,45 +214,45 @@ impl EngineAction for Brawl {
                     [
                         format!(
                             "A brawl between {} and {}! {} seems to have gotten the upper hand.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            defender.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            defender.info.short_name()
                         ),
                         format!(
                             "An intense clash between {} and {} ends with {} coming out on top!",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            defender.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            defender.info.short_name()
                         ),
                         format!(
                             "A fierce fight between {} and {} concludes with {} gaining the upper hand!",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            defender.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            defender.info.short_name()
                         ),
                         format!(
                             "{} and {} engage in a heated scuffle, but {} emerges the winner.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            defender.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            defender.info.short_name()
                         ),
                         format!(
                             "It's {} versus {} in a wild brawl! {} prevails in the end.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            defender.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            defender.info.short_name()
                         ),
                         format!(
                             "{} and {} come to blows during the game. {} manages to give the best shots.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            defender.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            defender.info.short_name()
                         ),
                         format!(
                             "The battle between {} and {} wraps up with {} as the victor.",
-                            attacker.info.shortened_name(),
-                            defender.info.shortened_name(),
-                            defender.info.shortened_name()
+                            attacker.info.short_name(),
+                            defender.info.short_name(),
+                            defender.info.short_name()
                         ),
                     ]
                     .choose(rng)
