@@ -12,8 +12,8 @@ pub enum ShotDifficulty {
 }
 
 pub const RECOVERING_TIREDNESS_PER_SHORT_TICK: f32 = TirednessCost::LOW;
-pub const MIN_TIREDNESS_FOR_SUB: f32 = 10.0;
 pub const MIN_TIREDNESS_FOR_ROLL_DECLINE: f32 = 10.0;
+pub const MIN_TIREDNESS_FOR_SUB: f32 = MIN_TIREDNESS_FOR_ROLL_DECLINE;
 
 pub const BASE_ATTENDANCE: u32 = 60;
 pub const BRAWL_ACTION_PROBABILITY: f32 = 0.06;
